@@ -9,14 +9,13 @@ import re
 import sys
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, NoReturn, Optional, Sequence, Set, Tuple, Type, Union
-from unittest.mock import patch
 
 from .formatters import DefaultHelpFormatter, empty_help, formatter_context, get_env_var
 from .jsonnet import ActionJsonnet
 from .jsonschema import ActionJsonSchema
 from .link_arguments import ActionLink, ArgumentLinking
 from .loaders_dumpers import check_valid_dump_format, dump_using_format, get_loader_exceptions, loaders, load_value, load_value_context, yaml_load
-from .namespace import dict_to_namespace, is_meta_key, Namespace, split_key, split_key_leaf, strip_meta
+from .namespace import dict_to_namespace, is_meta_key, Namespace, patch_namespace, split_key, split_key_leaf, strip_meta
 from .signatures import is_pure_dataclass, SignatureArguments
 from .typehints import ActionTypeHint, is_subclass_spec
 from .typing import is_final_class
@@ -233,7 +232,7 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
         namespace = argcomplete_namespace(caller, self, namespace)
 
         try:
-            with patch('argparse.Namespace', Namespace), lenient_check_context(caller), ActionTypeHint.subclass_arg_context(self), load_value_context(self.parser_mode):
+            with patch_namespace(), lenient_check_context(caller), ActionTypeHint.subclass_arg_context(self), load_value_context(self.parser_mode):
                 namespace, args = self._parse_known_args(args, namespace)
         except (argparse.ArgumentError, ParserError) as ex:
             self.error(str(ex), ex)
@@ -260,7 +259,6 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
         skip_required: bool = False,
         skip_subcommands: bool = False,
         fail_no_subcommand: bool = True,
-        cfg_base: Optional[Namespace] = None,
         log_message: Optional[str] = None,
     ) -> Namespace:
         """Common parsing code used by other parse methods.
@@ -274,7 +272,6 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
             skip_required: Whether to skip check of required arguments.
             skip_subcommands: Whether to skip subcommand processing.
             fail_no_subcommand: Whether to fail if no subcommand given.
-            cfg_base: A base configuration object.
             log_message: Message to log at INFO level after parsing.
 
         Returns:
@@ -286,18 +283,7 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
         if not skip_subcommands:
             _ActionSubCommands.handle_subcommands(self, cfg, env=env, defaults=defaults, fail_no_subcommand=fail_no_subcommand)
 
-        if cfg_base is not None:
-            cfg = self.merge_config(cfg, cfg_base)
-
-        if env:
-            with _ActionPrintConfig.skip_print_config():
-                cfg_env = self.parse_env(defaults=defaults, _skip_check=True, _skip_subcommands=True)
-            cfg = self.merge_config(cfg, cfg_env)
-
-        elif defaults:
-            cfg = self.merge_config(cfg, self.get_defaults(skip_check=True))
-            with load_value_context(self.parser_mode):
-                ActionTypeHint.apply_appends(self, cfg)
+        if defaults:
             with lenient_check_context():
                 ActionTypeHint.add_sub_defaults(self, cfg)
 
@@ -318,6 +304,26 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
         return cfg
 
 
+    def _parse_defaults_and_environ(
+        self,
+        defaults: bool = True,
+        env: Optional[bool] = None,
+        environ: Union[Dict[str, str], os._Environ] = None,
+    ):
+        cfg = Namespace()
+        if defaults:
+            cfg = self.get_defaults(skip_check=True)
+
+        if env or (env is None and self._default_env):
+            if environ is None:
+                environ = os.environ
+            with load_value_context(self.parser_mode):
+                cfg_env = self._load_env_vars(env=environ, defaults=defaults)
+            cfg = self.merge_config(cfg_env, cfg)
+
+        return cfg
+
+
     def parse_args(  # type: ignore[override]
         self,
         args: Optional[Sequence[str]] = None,
@@ -349,7 +355,11 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
         argcomplete_autocomplete(self)
 
         try:
-            cfg, unk = self.parse_known_args(args=args, namespace=namespace)
+            cfg = self._parse_defaults_and_environ(defaults, env)
+            if namespace:
+                cfg = self.merge_config(namespace, cfg)
+
+            cfg, unk = self.parse_known_args(args=args, namespace=cfg)
             if unk:
                 self.error(f'Unrecognized arguments: {" ".join(unk)}')
 
@@ -393,7 +403,12 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
             ParserError: If there is a parsing error and error_handler=None.
         """
         try:
-            cfg = self._apply_actions(cfg_obj)
+            cfg = self._parse_defaults_and_environ(defaults, env)
+            if cfg_base:
+                cfg = self.merge_config(cfg_base, cfg)
+
+            cfg_obj = self._apply_actions(cfg_obj)
+            cfg = self.merge_config(cfg_obj, cfg)
 
             parsed_cfg = self._parse_common(
                 cfg=cfg,
@@ -402,7 +417,6 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
                 with_meta=with_meta,
                 skip_check=_skip_check,
                 skip_required=_skip_required,
-                cfg_base=cfg_base,
                 log_message='Parsed object.',
             )
 
@@ -412,7 +426,7 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
         return parsed_cfg
 
 
-    def _load_env_vars(self, env: Dict[str, str], defaults: bool) -> Namespace:
+    def _load_env_vars(self, env: Union[Dict[str, str], os._Environ], defaults: bool) -> Namespace:
         cfg = Namespace()
         actions = filter_default_actions(self._actions)
         for action in actions:
@@ -437,10 +451,11 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
                         try:
                             env_val = load_value(env_val)
                         except get_loader_exceptions():
-                            env_val = [env_val]  # type: ignore
+                            env_val = [env_val]
                     else:
-                        env_val = [env_val]  # type: ignore
+                        env_val = [env_val]
                 cfg[action.dest] = self._check_value_key(action, env_val, action.dest, cfg)
+        self._apply_actions(cfg)
         return cfg
 
 
@@ -466,16 +481,11 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
             ParserError: If there is a parsing error and error_handler=None.
         """
         try:
-            if env is None:
-                env = dict(os.environ)
-            with load_value_context(self.parser_mode):
-                cfg = self._load_env_vars(env=env, defaults=defaults)
-
-            self._apply_actions(cfg)
+            cfg = self._parse_defaults_and_environ(defaults, env=True, environ=env)
 
             parsed_cfg = self._parse_common(
                 cfg=cfg,
-                env=False,
+                env=True,
                 defaults=defaults,
                 with_meta=with_meta,
                 skip_check=_skip_check,
@@ -563,6 +573,10 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
             with load_value_context(self.parser_mode):
                 cfg = self._load_config_parser_mode(cfg_str, cfg_path, ext_vars, previous_config.get())
 
+            if defaults or env:
+                cfg_base = self._parse_defaults_and_environ(defaults, env)
+                cfg = self.merge_config(cfg, cfg_base)
+
             parsed_cfg = self._parse_common(
                 cfg=cfg,
                 env=env,
@@ -921,11 +935,12 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
                 cfg_file = self._load_config_parser_mode(default_config_file.get_content())
                 if key is not None:
                     cfg_file = cfg_file.get(key)
+                cfg = self.merge_config(cfg_file, cfg)
                 try:
                     with _ActionPrintConfig.skip_print_config():
-                        cfg_file = self._parse_common(
-                            cfg=cfg_file,
-                            env=None,
+                        cfg = self._parse_common(
+                            cfg=cfg,
+                            env=False,
                             defaults=False,
                             with_meta=None,
                             skip_check=skip_check,
@@ -933,7 +948,6 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
                         )
                 except (TypeError, KeyError, ParserError) as ex:
                     raise ParserError(f'Problem in default config file "{default_config_file}" :: {ex.args[0]}') from ex
-            cfg = self.merge_config(cfg_file, cfg)
             meta = cfg.get('__default_config__')
             if isinstance(meta, list):
                 meta.append(default_config_file)
@@ -1218,6 +1232,7 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
         cfg = cfg_to.clone()
         ActionTypeHint.discard_init_args_on_class_path_change(self, cfg, cfg_from)
         cfg.update(cfg_from)
+        ActionTypeHint.apply_appends(self, cfg)
         return cfg
 
 
@@ -1409,6 +1424,10 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
 
     @parser_mode.setter
     def parser_mode(self, parser_mode: str):
+        if parser_mode not in loaders and parser_mode == 'omegaconf' and omegaconf_support:
+            from .loaders_dumpers import set_loader
+            from .optionals import get_omegaconf_loader
+            set_loader('omegaconf', get_omegaconf_loader())
         if parser_mode not in loaders:
             raise ValueError(f'The only accepted values for parser_mode are {set(loaders.keys())}.')
         if parser_mode == 'jsonnet':
@@ -1439,12 +1458,6 @@ class ArgumentParser(ActionsContainer, ArgumentLinking, argparse.ArgumentParser)
         self._dump_header = dump_header
 
 
-if omegaconf_support:
-    from .loaders_dumpers import set_loader
-    from .optionals import get_omegaconf_loader
-    set_loader('omegaconf', get_omegaconf_loader())
-
-
 from .deprecated import parse_as_dict_patch, instantiate_subclasses_patch
 instantiate_subclasses_patch()
 if 'JSONARGPARSE_SKIP_DEPRECATION_PATCH' not in os.environ:
