@@ -32,12 +32,12 @@ from typing import (
 )
 
 from .actions import _ActionHelpClassPath, _find_action, _find_parent_action, _is_action_value_list
-from .loaders_dumpers import get_loader_exceptions, load_value
-from .namespace import Namespace, split_key_root
+from .loaders_dumpers import get_loader_exceptions, load_value, load_value_context
+from .namespace import Namespace
 from .typing import is_final_class, registered_types
 from .optionals import (
     argcomplete_warn_redraw_prompt,
-    files_completer,
+    get_files_completer,
     typing_extensions_import,
 )
 from .util import (
@@ -297,7 +297,8 @@ class ActionTypeHint(Action):
         for key in [k for k in cfg.keys() if k.endswith('+')]:
             action = _find_action(parser, key[:-1])
             if ActionTypeHint.supports_append(action):
-                val = action._check_type(cfg[key], append=True, cfg=cfg)
+                with load_value_context(parser.parser_mode):
+                    val = action._check_type(cfg[key], append=True, cfg=cfg)
                 cfg[key[:-1]] = val
                 cfg.pop(key)
 
@@ -432,6 +433,7 @@ class ActionTypeHint(Action):
             enum = self._typehint.__args__[0]
             return list(enum.__members__.keys())+['null']
         elif is_optional(self._typehint, Path):
+            files_completer = get_files_completer()
             return ['null'] + sorted(files_completer(prefix, **kwargs))
         elif chr(int(os.environ['COMP_TYPE'])) == '?':
             try:
