@@ -5,6 +5,7 @@ import os
 import pickle
 import sys
 import unittest
+import unittest.mock
 import warnings
 import yaml
 from io import StringIO
@@ -295,7 +296,8 @@ class ParsersTests(TempDirTestCase):
         cfg = parser.parse_args(['--cfg', input1_config_file])
         cfg_list = parser.get_config_files(cfg)
         self.assertEqual(default_config_file, str(cfg_list[0]))
-        self.assertEqual(input1_config_file, str(cfg_list[1]))
+        self.assertEqual(input2_config_file, str(cfg_list[1]))  # From os.environ['APP_CFG']
+        self.assertEqual(input1_config_file, str(cfg_list[2]))
 
         for key in ['APP_CFG', 'APP_OP1']:
             del os.environ[key]
@@ -538,6 +540,15 @@ class AdvancedFeaturesTests(unittest.TestCase):
         self.assertEqual(cfg, Namespace(subcommand=None))
 
 
+    def test_subcommand_without_options(self):
+        parser = ArgumentParser()
+        subcommands = parser.add_subcommands()
+        subparser = ArgumentParser()
+        subcommands.add_subcommand('foo', subparser)
+        cfg = parser.parse_args(['foo'])
+        self.assertEqual(cfg.subcommand, 'foo')
+
+
     def test_subcommand_print_config_default_env_issue_126(self):
         subparser = ArgumentParser()
         subparser.add_argument('--config', action=ActionConfigFile)
